<?php

namespace Drupal\acquia_contenthub_publisher\EventSubscriber\HandleWebhook;

use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\HandleWebhookEvent;
use Drupal\acquia_contenthub_publisher\PublisherTracker;
use Drupal\Core\Database\Connection;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class UpdatePublished implements EventSubscriberInterface {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  public function __construct(Connection $database) {
    $this->database = $database;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::HANDLE_WEBHOOK][] = 'onHandleWebhook';
    return $events;
  }

  public function onHandleWebhook(HandleWebhookEvent $event) {
    $payload = $event->getPayload();
    $client = $event->getClient();
    if ($payload['status'] == 'successful' && $payload['crud'] == 'update' && $payload['initiator'] == $client->getSettings()->getUuid()) {
      if (isset($payload['assets']) && count($payload['assets'])) {
        foreach ($payload['assets'] as $asset) {
          $query = $this->database->update('acquia_contenthub_publisher_export_tracking')
            ->fields(['status' => PublisherTracker::CONFIRMED]);
          $query->condition('entity_uuid', $asset['uuid']);
          $query->execute();
        }
      }
    }
  }

}
