<?php

namespace Drupal\acquia_contenthub\Event;

use Acquia\ContentHubClient\CDFObject;
use Drupal\Core\Entity\EntityInterface;
use Symfony\Component\EventDispatcher\Event;

class CreateCDFEntityEvent extends Event {

  /**
   * The entity being serialized.
   *
   * @var \Drupal\Core\Entity\ContentEntityInterface
   */
  protected $entity;

  /**
   * The array of entity dependencies.
   *
   * @var array
   */
  protected $dependencies;

  /**
   * The CDF Objects generated for this entity.
   *
   * @var \Acquia\ContentHubClient\CDFObject[]
   */
  protected $cdfs = [];

  /**
   * SerializeCDFEntityField constructor.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity being serialized.
   */
  public function __construct(EntityInterface $entity, array $dependencies = []) {
    $this->entity = $entity;
    $this->dependencies = $dependencies;
  }

  /**
   * The entity to which the field belongs.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface
   */
  public function getEntity() {
    return $this->entity;
  }

  public function getDependencies() {
    return $this->dependencies;
  }

  public function addCDF(CDFObject $cdf) {
    $this->cdfs[] = $cdf;
  }

  /**
   * @param $uuid
   *
   * @return \Acquia\ContentHubClient\CDFObject
   */
  public function getCDF($uuid) {
    foreach ($this->cdfs as $cdf) {
      if ($cdf->getUuid() == $uuid) {
        return $cdf;
      }
    }
  }

  /**
   * @return \Acquia\ContentHubClient\CDFObject[]
   */
  public function getCDFs() {
    return $this->cdfs;
  }

}