<?php


namespace Drupal\acquia_contenthub\Event;


use Acquia\ContentHubClient\CDFObject;
use Drupal\Core\Entity\EntityInterface;
use Symfony\Component\EventDispatcher\Event;

/**
 * The event fired for content hub entity imports.
 *
 * This event has no setters because it is purely informational. It informs
 * subscribers of an event and invites them to perform related actions but not
 * to modify any variables relevant to the event itself.
 */
class EntityImportEvent extends Event {

  /**
   * The entity that was imported.
   *
   * @var \Drupal\Core\Entity\EntityInterface
   */
  protected $entity;

  /**
   * The source array data that was used to create the entity.
   *
   * This is useful for situations where you might want to refer to the data
   * as it existed before an entity was created.
   *
   * @var CDFObject
   */
  protected $entityData;

  public function __construct(EntityInterface $entity, CDFObject $entity_data) {
    $this->entity = $entity;
    $this->entityData = $entity_data;
  }

  /**
   * Get the entity that was imported.
   *
   * @return \Drupal\Core\Entity\EntityInterface
   */
  public function getEntity() {
    return $this->entity;
  }

  /**
   * Get the entity data that was used to create the entity.
   *
   * @return CDFObject
   */
  public function getEntityData() {
    return $this->entityData;
  }

}
