<?php

namespace Drupal\acquia_contenthub\Event;

use Acquia\ContentHubClient\ContentHubClient;
use Symfony\Component\EventDispatcher\Event;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

class HandleWebhookEvent extends Event {

  /**
   * The request object.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $request;

  /**
   * The request payload.
   *
   * @var array
   */
  protected $payload;

  /**
   * @todo this should be \Acquia\Hmac\KeyInterface once ContentHub service is properly squared away for HMAC 2.
   *
   * @var bool
   */
  protected $key;

  /**
   * The ContentHub Client.
   *
   * @var \Acquia\ContentHubClient\ContentHubClient
   */
  protected $client;

  /**
   * The response to send back to the ContentHub service.
   *
   * @var mixed
   */
  protected $response;

  /**
   * HandleWebhookEvent constructor.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   * @param array $payload
   * @param bool $key
   * @param \Acquia\ContentHubClient\ContentHubClient $client
   */
  public function __construct(Request $request, array $payload, $key, ContentHubClient $client) {
    $this->request = $request;
    $this->payload = $payload;
    $this->key = $key;
    $this->client = $client;
  }

  /**
   * @return \Symfony\Component\HttpFoundation\Request
   */
  public function getRequest() {
    return $this->request;
  }

  /**
   * @return array
   */
  public function getPayload() {
    return $this->payload;
  }

  /**
   * @return mixed
   */
  public function getKey() {
    return $this->key;
  }

  /**
   * Sets the response to return for this webhook.
   *
   * @param mixed $response
   *   The response for this webhook.
   */
  public function setResponse($response) {
    $this->response = $response;
  }

  /**
   * Whether a response has been set for this webhook.
   *
   * @return bool
   */
  public function hasResponse() {
    return (bool) $this->response;
  }

  /**
   * Get the response for this webhook.
   *
   * @return mixed
   */
  public function getResponse() {
    if ($this->hasResponse()) {
      return $this->response;
    }
    return new Response('');
  }

  /**
   * The ContentHub Client.
   *
   * @return \Acquia\ContentHubClient\ContentHubClient
   */
  public function getClient() {
    return $this->client;
  }

}
