<?php

namespace Drupal\acquia_contenthub\Event;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\depcalc\DependencyStack;
use Symfony\Component\EventDispatcher\Event;

class UnserializeCDFAttributeEvent extends Event {

  /**
   * The entity type.
   *
   * @var \Drupal\Core\Entity\EntityTypeInterface
   */
  protected $entityType;

  /**
   * The field name.
   *
   * @var string
   */
  protected $fieldName;

  /**
   * The attribute array.
   *
   * @var array
   */
  protected $attribute;

  /**
   * The field metadata of the attribute.
   *
   * @var array
   */
  protected $metadata;

  /**
   * The dependency stack.
   *
   * @var \Drupal\depcalc\DependencyStack
   */
  protected $stack;

  /**
   * The value array.
   *
   * @var array
   */
  protected $value = [];

  /**
   * UnserializeCDFAttributeEvent constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type id.
   * @param string $field_name
   *   The field name.
   * @param array $attribute
   *   The attribute array.
   * @param array $metadata
   * @param \Drupal\depcalc\DependencyStack $stack
   */
  public function __construct(EntityTypeInterface $entity_type, $field_name, array $attribute, array $metadata, DependencyStack $stack) {
    $this->entityType = $entity_type;
    $this->fieldName = $field_name;
    $this->attribute = $attribute;
    $this->metadata = $metadata;
    $this->stack = $stack;
  }

  /**
   * Get the entity type for this attribute.
   *
   * @return \Drupal\Core\Entity\EntityTypeInterface
   */
  public function getEntityType() {
    return $this->entityType;
  }

  /**
   * Get the field name to attribute values to.
   *
   * @return string
   */
  public function getFieldName() {
    return $this->fieldName;
  }

  /**
   * Change field name in the very narrow case where one field affects another.
   *
   * @param string $field_name
   */
  public function setFieldName($field_name) {
    $this->fieldName = $field_name;
  }

  /**
   * The CDF attribute values.
   *
   * @return array
   */
  public function getAttribute() {
    return $this->attribute;
  }

  /**
   * The attribute field type.
   *
   * @return array
   */
  public function getFieldMetadata() {
    return $this->metadata;
  }

  /**
   * Set the value use to instantiate an entity's field values.
   *
   * @param array $value
   */
  public function setValue(array $value) {
    $this->value = $value;
  }

  /**
   * Get the value intended to be used to instantiate a field's values.
   *
   * @return array
   */
  public function getValue() {
    return $this->value;
  }

  /**
   * Get the dependency stack
   *
   * @return \Drupal\depcalc\DependencyStack
   */
  public function getStack() {
    return $this->stack;
  }

}
