<?php


namespace Drupal\acquia_contenthub\EventSubscriber\CDF;


use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\CreateCDFEntityEvent;
use Drupal\acquia_contenthub\Event\ParseCDFEntityEvent;
use Drupal\acquia_contenthub\Plugin\FileSchemeHandler\FileSchemeHandlerManagerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class FileEntityHandler implements EventSubscriberInterface {

  /**
   * The file scheme handler manager.
   *
   * @var \Drupal\acquia_contenthub\Plugin\FileSchemeHandler\FileSchemeHandlerManagerInterface
   */
  protected $manager;

  public function __construct(FileSchemeHandlerManagerInterface $manager) {
    $this->manager = $manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::CREATE_CDF_OBJECT][] = ['onCreateCDF', 90];
    $events[AcquiaContentHubEvents::PARSE_CDF][] = ['onParseCDF', 110];
    return $events;
  }

  /**
   * Add attributes to file entity CDF representations.
   *
   * @param \Drupal\acquia_contenthub\Event\CreateCDFEntityEvent $event
   *   The create CDF entity event.
   */
  public function onCreateCDF(CreateCDFEntityEvent $event) {
    if ($event->getEntity()->getEntityTypeId() == 'file') {
      /** @var \Drupal\file\FileInterface $entity */
      $entity = $event->getEntity();
      $handler = $this->manager->getHandlerForFile($entity);
      $handler->addAttributes($event->getCDF($entity->uuid()), $entity);
    }
  }

  /**
   * Parse CDF attributes to import files as necessary.
   *
   * @param \Drupal\acquia_contenthub\Event\ParseCDFEntityEvent $event
   *   The Parse CDF Entity Event.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function onParseCDF(ParseCDFEntityEvent $event) {
    $cdf = $event->getCDF();
    if ($cdf->getAttribute('file_scheme')) {
      $scheme = $cdf->getAttribute('file_scheme')->getValue()['und'];
      $handler = $this->manager->createInstance($scheme);
      $handler->getFile($cdf);
    }
  }

}
