<?php


namespace Drupal\acquia_contenthub\EventSubscriber\CDFAttributes;

use Acquia\ContentHubClient\CDFAttribute;
use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\CDFAttributesEvent;
use Drupal\Core\Entity\ContentEntityInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class EntityTagsCDFAttribute implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::POPULATE_CDF_ATTRIBUTES][] = ['onPopulateAttributes', 100];
    return $events;
  }

  public function onPopulateAttributes(CDFAttributesEvent $event) {
    $entity = $event->getEntity();
    if ($entity instanceof ContentEntityInterface) {
      $cdf = $event->getCDF();
      $tags = [];
      /**
       * @var string $field_name
       * @var \Drupal\Core\Field\FieldItemListInterface $field
       */
      foreach ($entity as $field_name => $field) {
        if ($field->getFieldDefinition()->getType() == 'entity_reference' && $field->getFieldDefinition()->getSettings()['target_type'] == 'taxonomy_term') {
          foreach ($field as $item) {
            if (!$item->entity) {
              $entity = \Drupal::entityTypeManager()->getStorage($field->getFieldDefinition()->getSetting('target_type'))->load($item->getValue()['target_id']);
              if (is_null($entity)) {
                continue;
              }
              $item->entity = $entity;
            }
            $tags[] = $item->entity->uuid();
          }
        }
      }
      if ($tags) {
        $cdf->addAttribute('tags', CDFAttribute::TYPE_ARRAY_REFERENCE, $tags);
      }
    }
  }

}
