<?php


namespace Drupal\acquia_contenthub\EventSubscriber\SerializeContentField;


use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\SerializeCDFEntityField;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class PathFieldSerializer extends FallbackFieldSerializer implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::SERIALIZE_CONTENT_ENTITY_FIELD][] = ['onSerializeContentField', 5];
    return $events;
  }

  /**
   * Manipulate the path properties.
   *
   * @param \Drupal\acquia_contenthub\Event\SerializeCDFEntityField $event
   *   The content entity field serialization event.
   */
  public function onSerializeContentField(SerializeCDFEntityField $event) {
    if ($event->getField()->getFieldDefinition()->getType() == 'path') {
      parent::onSerializeContentField($event);
      $values = $event->getFieldData();
      foreach ($values['value'] as $langcode => $value) {
        // @todo check core's behavior around empty paths.
        if (!empty($value['alias'])) {
          $value['source'] = "";
          $value['pid'] = "";
          $values['value'][$langcode] = $value;
          $event->setFieldData($values);
        }
        else {
          $event->stopPropagation();
        }
      }
    }
  }

}
