<?php

namespace Drupal\acquia_contenthub\EventSubscriber\UnserializeCDFAttribute;

use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\UnserializeCDFAttributeEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Entity/image/file field reference handling.
 */
class EntityReferenceField implements EventSubscriberInterface {
  use FieldEntityDepedencyTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::UNSERIALIZE_CDF_ATTRIBUTE] = ['onUnserializeAttribute', 10];
    return $events;
  }

  /**
   * Extracts the target storage and retrieves the referenced entity.
   *
   * @param \Drupal\acquia_contenthub\Event\UnserializeCDFAttributeEvent $event
   *   The unserialize event.
   */
  public function onUnserializeAttribute(UnserializeCDFAttributeEvent $event) {
    $attribute = $event->getAttribute();
    if (in_array($event->getFieldMetadata()['type'], ['file', 'image', 'entity_reference', 'entity_reference_revisions'])) {
      $values = [];
      if (!empty($attribute['value'])) {
        foreach ($attribute['value'] as $langcode => $value) {
          if (!is_array($value)) {
            $entity = $this->getEntity($value, $event);
            $values[$langcode][$event->getFieldName()] = $entity->id();
            // @todo handle single value ERR fields.
          } else {
            foreach ($value as $delta => $item) {
              $entity = $this->getEntity($item, $event);
              if ($event->getFieldMetadata()['type'] == 'entity_reference_revisions') {
                /** @var \Drupal\Core\Entity\RevisionableInterface $entity */
                $values[$langcode][$event->getFieldName()][] = [
                  'target_id' => $entity->id(),
                  'target_revision_id' => $entity->getRevisionId(),
                ];
              }
              else {
                $values[$langcode][$event->getFieldName()][]['target_id'] = $entity->id();
              }
            }
          }
        }
      }
      $event->setValue($values);
      $event->stopPropagation();
    }
  }

}
