<?php


namespace Drupal\acquia_contenthub\EventSubscriber\UnserializeCDFAttribute;


use Drupal\acquia_contenthub\Event\UnserializeCDFAttributeEvent;

trait FieldEntityDepedencyTrait {

  /**
   * Get an entity from the dependency stack.
   *
   * @param string $uuid
   *   The uuid of the entity to retrieve.
   * @param \Drupal\acquia_contenthub\Event\UnserializeCDFAttributeEvent $event
   *   The subscribed event.
   *
   * @return \Drupal\Core\Entity\EntityInterface
   *   The retrieved entity.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  protected function getEntity($uuid, UnserializeCDFAttributeEvent $event) {
    // Check stack first because uuids are referenced from origin, not local.
    if ($event->getStack()->hasDependency($uuid)) {
      return $event->getStack()->getDependency($uuid)->getEntity();
    }
    // Only fall back to local uuids as an absolute last resort.
    $storage = \Drupal::entityTypeManager()->getStorage($event->getFieldMetadata()['target']);
    return reset($storage->loadByProperties(['uuid' => $uuid]));
  }

}