<?php

namespace Drupal\acquia_contenthub\EventSubscriber\UnserializeCDFAttribute;

use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\UnserializeCDFAttributeEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Manual handling for text item fields filter references.
 */
class TextItemField implements EventSubscriberInterface {
  use FieldEntityDepedencyTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::UNSERIALIZE_CDF_ATTRIBUTE] = ['onUnserializeAttribute', 100];
    return $events;
  }

  /**
   * Extract the stored filter_format uuid and retrieve the entity id.
   *
   * @param \Drupal\acquia_contenthub\Event\UnserializeCDFAttributeEvent $event
   *   The unserialize event.
   */
  public function onUnserializeAttribute(UnserializeCDFAttributeEvent $event) {
    if (in_array($event->getFieldMetadata()['type'], ['text_with_summary', 'text', 'text_long'])) {
      $attribute = $event->getAttribute();
      $values = [];
      foreach ($attribute['value'] as $langcode => $value) {
        foreach ($value as $delta => &$item) {
          if ($item['format']) {
            $filter = $this->getEntity($item['format'], $event);
            $item['format'] = $filter->id();
          }
        }
        $values[$langcode][$event->getFieldName()] = $value;
      }
      $event->setValue($values);
      $event->stopPropagation();
    }
  }

}
