<?php


namespace Drupal\acquia_contenthub\Plugin\FileSchemeHandler;

use Acquia\ContentHubClient\CDFAttribute;
use Acquia\ContentHubClient\CDFObject;
use Drupal\Core\Plugin\PluginBase;
use Drupal\Core\Url;
use Drupal\file\FileInterface;

/**
 * @FileSchemeHandler(
 *   id = "public",
 *   label = @Translation("Public file handler")
 * )
 */
class PublicFileSchemeHandler extends PluginBase implements FileSchemeHandlerInterface {

  /**
   * {@inheritdoc}
   */
  public function addAttributes(CDFObject $object, FileInterface $file) {
    $uri = $file->getFileUri();
    $directory_path = $this->getStreamWrapperManager()->getViaUri($uri)->getDirectoryPath();
    $url = Url::fromUri('base:' . $directory_path . '/' . file_uri_target($uri), ['absolute' => TRUE])->toString();
    $object->addAttribute('file_scheme', CDFAttribute::TYPE_STRING, 'public');
    $object->addAttribute('file_location', CDFAttribute::TYPE_STRING, $url);
    $object->addAttribute('file_uri', CDFAttribute::TYPE_STRING, $uri);
  }

  /**
   * {@inheritdoc}
   */
  public function getFile(CDFObject $object) {
    if ($object->getAttribute('file_location') && $object->getAttribute('file_uri')) {
      $url = $object->getAttribute('file_location')->getValue()['und'];
      $contents = file_get_contents($url);
      $uri = $object->getAttribute('file_uri')->getValue()['und'];
      return file_unmanaged_save_data($contents, $uri, FILE_EXISTS_REPLACE);
    }
    return FALSE;
  }

  /**
   * Gets the stream wrapper manager service.
   *
   * @return \Drupal\Core\StreamWrapper\StreamWrapperManagerInterface
   *   The stream wrapper manager service
   *
   * @todo Properly inject this service in Drupal 9.0.x.
   */
  protected function getStreamWrapperManager() {
    return \Drupal::service('stream_wrapper_manager');
  }

}
